import { fileURLToPath, URL } from 'node:url'

import { defineConfig } from 'vite'
import vue from '@vitejs/plugin-vue'
import legacy from '@vitejs/plugin-legacy'
import Pages from 'vite-plugin-pages'
import styleImport, { VantResolve } from 'vite-plugin-style-import';

import pxtovw from 'postcss-px-to-viewport'
const loader_pxtovw = pxtovw({
  unitToConvert: 'px',
  viewportWidth: 320,
  unitPrecision: 5,
  propList: ['*'],
  viewportUnit: 'vw',
  fontViewportUnit: 'vw',
  selectorBlackList: [],
  minPixelValue: 1,
  mediaQuery: false,
  replace: true,
  exclude: [],
  landscape: false,
  landscapeUnit: 'vw',
  landscapeWidth: 568
})

// https://vitejs.dev/config/
export default {
  plugins: [
    vue({ reactivityTransform: true }),
    Pages({
      dirs: ['src/views', 'src/modules'],
      extensions: ['vue'],
      exclude: ['**/components/*.vue']
    }),
    legacy({
      targets: ['defaults', 'not IE 11']
    }),
    styleImport({
      resolves: [VantResolve()],
      libs: [{
        libraryName: 'vant',
        esModule: false,
        resolveStyle: (name) => `vant/es/${name}/style/index`
      }],
    }),
  ],
  css: {
    postcss: {
      plugins: [loader_pxtovw]
    }
  },
  resolve: {
    alias: {
      '@': fileURLToPath(new URL('./src', import.meta.url))
    }
  },
  server: {
    host: '0.0.0.0',
    port: 5678
  }
}
